OC.L10N.register(
    "settings",
    {
    "Private" : "Riêng tư",
    "Only visible to people matched via phone number integration through Talk on mobile" : "Chỉ hiển thị với những người phù hợp thông qua tích hợp số điện thoại thông qua Talk trên thiết bị di động",
    "Local" : "Cục bộ",
    "Only visible to people on this instance and guests" : "Chỉ hiển thị với mọi người trong trường hợp này và khách",
    "Federated" : "Federated",
    "Only synchronize to trusted servers" : "Chỉ đồng bộ đối với máy chủ tin cậy",
    "Published" : "Đã đăng",
    "Synchronize to trusted servers and the global and public address book" : "Đồng bộ với máy chủ tin cậy và sổ địa chỉ toàn cầu và công khai",
    "Verify" : "Xác minh",
    "Verifying …" : "Đang xác minh ...",
    "Unable to change password" : "Không thể thay đổi mật khẩu",
    "Very weak password" : "Mật khẩu rất yếu",
    "Weak password" : "Mật khẩu yếu",
    "So-so password" : "Mật khẩu tương tự",
    "Good password" : "Mật khẩu tốt",
    "Strong password" : "Mật khẩu mạnh",
    "Groups" : "Nhóm",
    "Group list is empty" : "Danh sách nhóm trống",
    "Unable to retrieve the group list" : "Không thể truy xuất danh sách nhóm",
    "{actor} added you to group {group}" : "{actor} đã thêm bạn vào nhóm {group}",
    "You added {user} to group {group}" : "Bạn đã thêm {user} vào nhóm {group}",
    "{actor} added {user} to group {group}" : "{actor} đã thêm {user} vào nhóm {group}",
    "An administrator added you to group {group}" : "Quản trị viên đã thêm bạn vào nhóm {group}",
    "An administrator added {user} to group {group}" : "Quản trị viên đã thêm {user} vào nhóm {group}",
    "{actor} removed you from group {group}" : "{actor} đã xóa bạn khỏi nhóm {group}",
    "You removed {user} from group {group}" : "Bạn đã xóa {user} khỏi nhóm {group}",
    "{actor} removed {user} from group {group}" : "{actor} đã xóa {user} khỏi nhóm {group}",
    "An administrator removed you from group {group}" : "Quản trị viên đã xóa bạn khỏi nhóm {group}",
    "An administrator removed {user} from group {group}" : "Quản trị viên đã xóa {user} khỏi nhóm {group}",
    "Your <strong>group memberships</strong> were modified" : "<strong>quyền thành viên nhóm</strong> của bạn  đã bị thay đổi",
    "{actor} changed your password" : "{actor} đã thay đổi mật khẩu của bạn",
    "You changed your password" : "Bạn đã thay đổi mật khẩu",
    "Your password was reset by an administrator" : "Mật khẩu của bạn đã được khôi phục bởi quản trị viên",
    "Your password was reset" : "Đã đặt lại mật khẩu",
    "{actor} changed your email address" : "{actor} đã thay đổi địa chỉ email của bạn",
    "You changed your email address" : "Bạn đã thay đổi địa chỉ email",
    "Your email address was changed by an administrator" : "Địa chỉ email của bạn đã được thay đổi bởi quản trị viên",
    "You created an app password for a session named \"{token}\"" : "Đã tạo mật khẩu ứng dụng cho phiên có tên \"{token}\"",
    "An administrator created an app password for a session named \"{token}\"" : "Quản trị viên đã tạo mật khẩu ứng dụng cho phiên có tên \"{token}\"",
    "You deleted app password \"{token}\"" : "Bạn đã xóa ứng dụng mật khẩu \"{token}\"",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Bạn đã đổi tên ứng dụng mật khẩu \"{token}\" thành \"{newToken}\"",
    "You granted filesystem access to app password \"{token}\"" : "Bạn đã cấp quyền truy cập hệ thống tệp cho ứng dụng mật khẩu \"{token}\"",
    "You revoked filesystem access from app password \"{token}\"" : "Bạn đã thu hồi quyền truy cập hệ thống tệp từ ứng dụng mật khẩu \"{token}\"",
    "Security" : "Bảo mật",
    "You successfully logged in using two-factor authentication (%1$s)" : "Bạn đã đăng nhập thành công bằng xác thực hai yếu tố  (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Thử đăng nhập bằng xác thực hai yếu tố không thành công (%1$s)",
    "Remote wipe was started on %1$s" : "Xóa từ xa đã được bắt đầu vào %1$s",
    "Remote wipe has finished on %1$s" : "Xóa từ xa đã kết thúc vào %1$s",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "<strong>mật khẩu</strong> hoặc <strong>email</strong> đã được sửa đổi",
    "Settings" : "Cài đặt",
    "Could not remove app." : "Không thể xoá ứng dụng.",
    "Could not update app." : "Không thể cập nhật ứng dụng.",
    "Wrong password" : "Mật khẩu không chính xác",
    "Unable to change personal password" : "Không thể thay đổi mật khẩu cá nhân",
    "Saved" : "Đã lưu",
    "Unable to change password. Password too long." : "Không thể đổi mật khẩu. Mật khẩu quá dài.",
    "Authentication error" : "Lỗi xác thực",
    "Wrong admin recovery password. Please check the password and try again." : "Sai mật khẩu khôi phục quản trị viên. Vui lòng kiểm tra mật khẩu và thử lại.",
    "Administrator documentation" : "Tài liệu quản trị viên",
    "User documentation" : "Tài liệu người dùng",
    "Nextcloud help overview" : "Tổng quan trợ giúp",
    "Invalid SMTP password." : "Mật khẩu SMTT không chính xác.",
    "Email setting test" : "Kiểm tra cài đặt email",
    "Well done, %s!" : "Làm rất tốt, %s!",
    "If you received this email, the email configuration seems to be correct." : "Nếu bạn nhận được email này, cấu hình email có vẻ đúng.",
    "Email could not be sent. Check your mail server log" : "Email không thể gửi được. Kiểm tra nhật ký máy chủ email của bạn",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Một vấn đề xảy ra trong khi gửi email. Vui lòng sửa lại cài đặt của bạn. (Lỗi: %s)",
    "Invalid mail address" : "Địa chỉ email không hợp lệ",
    "Settings saved" : "Cấu hình đã được lưu",
    "Unable to change full name" : "Họ và tên không thể thay đổi ",
    "Unable to change email address" : "Không thể thay đổi địa chỉ email",
    "Unable to set invalid phone number" : "Không thể đặt số điện thoại không hợp lệ",
    "Unable to set invalid website" : "Không thể đặt trang web không hợp lệ",
    "Some account data was invalid" : "Một số dữ liệu tài khoản không hợp lệ",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Để xác minh tài khoản Twitter của bạn, hãy đăng tweet sau đây trên Twitter (vui lòng đảm bảo đăng nó mà không có bất kỳ ngắt dòng nào):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Để xác minh trang web của bạn, hãy lưu trữ nội dung sau trong web-root của bạn tại '.well-known/CloudIdVerificationCode.txt' (vui lòng đảm bảo rằng văn bản hoàn chỉnh nằm trong một dòng):",
    "%1$s changed your password on %2$s." : "%1$s đã thay đổi mật khẩu của bạn trên %2$s",
    "Your password on %s was changed." : "Mật khẩu của bạn trên %s đã được thay đổi.",
    "Your password on %s was reset by an administrator." : "Mật khẩu của bạn trên %s đã được quản trị viên đặt lại.",
    "Your password on %s was reset." : "Mật khẩu của bạn trên %s đã được đặt lại.",
    "Password for %1$s changed on %2$s" : "Mật khẩu cho %1$s đã thay đổi trên %2$s",
    "Password changed for %s" : "Mật khẩu đã thay đổi cho %s",
    "If you did not request this, please contact an administrator." : "Nếu bạn không yêu cầu điều này, xin vui lòng liên hệ với quản trị viên.",
    "Your email address on %s was changed." : "Địa chỉ email của bạn trên %s đã được thay đổi.",
    "Your email address on %s was changed by an administrator." : "Địa chỉ email của bạn trên %s đã được thay đổi bởi quản trị viên.",
    "Email address for %1$s changed on %2$s" : "Địa chỉ email cho %1$s đã được thay đổi trên %2$s",
    "Email address changed for %s" : "Địa chỉ email đã được thay đổi cho %s",
    "The new email address is %s" : "Địa chỉ email mới là %s",
    "Your %s account was created" : "Tài khoản %s của bạn đã được tạo",
    "Welcome aboard" : "Chào mừng bạn",
    "Welcome aboard %s" : "Chào mừng bạn %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Chào mừng bạn đến với tài khoản %s của bạn, bạn có thể thêm, bảo vệ và chia sẻ dữ liệu của mình.",
    "Set your password" : "Đặt mật khẩu của bạn",
    "Go to %s" : "Đi tới %s",
    "Install Client" : "Cài đặt máy khách",
    "Apps" : "Ứng dụng",
    "Personal" : "Cá nhân",
    "Administration" : "Quản trị viên",
    "Users" : "Người dùng",
    "Additional settings" : "Cài đặt bổ sung",
    "Administration privileges" : "Đặc quyền quản trị",
    "Groupware" : "Phần mềm nhóm",
    "Overview" : "Tổng quan",
    "Basic settings" : "Thiết lập cơ bản",
    "Sharing" : "Chia sẻ",
    "Availability" : "Khả dụng",
    "Calendar" : "Lịch",
    "Personal info" : "Thông tin cá nhân",
    "Mobile & desktop" : "Điện thoại di động và máy tính để bàn",
    "Artificial Intelligence" : "Trí tuệ nhân tạo",
    "Email server" : "Máy chủ mail",
    "Background jobs" : "Các công việc trong nền",
    "Unlimited" : "Không giới hạn",
    "Verifying" : "Đang xác minh",
    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Thư mục dữ liệu và tệp của bạn có thể truy cập được từ internet. Tệp .htaccess không hoạt động. Chúng tôi khuyên bạn nên cấu hình máy chủ web của mình để thư mục dữ liệu không thể truy cập được nữa hoặc di chuyển thư mục dữ liệu ra ngoài thư mục gốc tài liệu máy chủ web.",
    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "Cơ sở dữ liệu thiếu một số cột tùy chọn. Do thực tế là việc thêm cột trên các bảng lớn có thể mất một chút thời gian, chúng không được thêm tự động khi chúng có thể là tùy chọn. Bằng cách chạy \"occ db:add-missing-columns\", các cột bị thiếu đó có thể được thêm thủ công trong khi phiên bản tiếp tục chạy. Sau khi các cột được thêm vào, một số tính năng có thể cải thiện khả năng phản hồi hoặc khả năng sử dụng.",
    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "Cơ sở dữ liệu thiếu một số khóa chính. Do thực tế là việc thêm các khóa chính trên các bảng lớn có thể mất một thời gian, chúng không được thêm tự động. Bằng cách chạy \"occ db:add-missing-primary-keys\", các khóa chính bị thiếu đó có thể được thêm thủ công trong khi phiên bản tiếp tục chạy.",
    "This instance is running in debug mode. Only enable this for local development and not in production environments." : "Phiên bản này đang chạy ở chế độ gỡ lỗi. Chỉ kích hoạt điều này cho sự phát triển của địa phương chứ không phải trong môi trường sản xuất.",
    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective ISO 3166-1 code of the region to your config file." : "Cài đặt của bạn chưa đặt vùng điện thoại mặc định. Điều này là bắt buộc để xác thực số điện thoại trong cài đặt hồ sơ mà không cần mã quốc gia. Để cho phép các số không có mã quốc gia, vui lòng thêm 'default_phone_khu vực' với mã ISO 3166-1 tương ứng của khu vực vào tệp cấu hình của bạn.",
    "Internet connectivity" : "Kết nối mạng",
    "Internet connectivity is disabled in configuration file." : "Kết nối Internet bị vô hiệu hóa trong tập tin cấu hình.",
    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Máy chủ này không có kết nối internet hoạt động: Không thể truy cập nhiều điểm cuối. Điều này có nghĩa là một số tính năng như gắn bộ nhớ ngoài, thông báo về bản cập nhật hoặc cài đặt ứng dụng của bên thứ ba sẽ không hoạt động. Truy cập tệp từ xa và gửi email thông báo cũng có thể không hoạt động. Thiết lập kết nối từ máy chủ này với internet để tận hưởng tất cả các tính năng.",
    "Disabled" : "Đã vô hiệu",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "Định dạng mã hóa phía máy chủ cũ được bật. Chúng tôi khuyên bạn nên tắt tính năng này.",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended.",
    "Supported" : "Đã hỗ trợ",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "PHP của bạn không có hỗ trợ FreeType, dẫn đến vỡ ảnh hồ sơ và giao diện cài đặt.",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP dường như không được thiết lập đúng cách để truy vấn các biến môi trường hệ thống. Thử nghiệm với getenv(\"PATH\") trả về một phản hồi trống.",
    "PHP modules" : "Mô-đun PHP",
    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "Mô-đun PHP OPcache không được tải. Để có hiệu suất tốt hơn, bạn nên tải nó vào bản cài đặt PHP của mình.",
    "You are currently running PHP %s." : "Bạn hiện đang chạy PHP %s.",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Cấu hình chỉ đọc đã được bật. Điều này ngăn thiết lập một số cấu hình thông qua giao diện web. Hơn nữa, tệp cần được ghi theo cách thủ công cho mỗi lần cập nhật.",
    "Nextcloud configuration file is writable" : "Tệp cấu hình Nextcloud có thể ghi được",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Cơ sở dữ liệu của bạn không chạy với mức cô lập giao dịch \"READ COMMITTED\". Điều này có thể gây ra sự cố khi nhiều hành động được thực thi song song.",
    "Profile information" : "Thông tin cá nhân",
    "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Ảnh hồ sơ, tên đầy đủ, email, số điện thoại, địa chỉ, trang web, Twitter, tổ chức, vai trò, tiêu đề, tiểu sử và liệu hồ sơ của bạn có được bật hay không",
    "Nextcloud settings" : "Cài đặt Cloud",
    "Enable" : "Bật",
    "Machine translation" : "Dịch máy",
    "Machine translation can be implemented by different apps. Here you can define the precedence of the machine translation apps you have installed at the moment." : "Dịch máy có thể được thực hiện bởi các ứng dụng khác nhau. Tại đây, bạn có thể xác định mức độ ưu tiên của ứng dụng dịch máy mà bạn đã cài đặt vào lúc này.",
    "Image generation" : "Tạo hình ảnh",
    "Image generation can be implemented by different apps. Here you can set which app should be used." : "Việc tạo hình ảnh có thể được thực hiện bởi các ứng dụng khác nhau. Tại đây bạn có thể đặt ứng dụng nào sẽ được sử dụng.",
    "None of your currently installed apps provide image generation functionality" : "Không có ứng dụng nào bạn cài đặt hiện tại cung cấp chức năng tạo hình ảnh",
    "Text processing" : "Xử lý văn bản",
    "Text processing tasks can be implemented by different apps. Here you can set which app should be used for which task." : "Các tác vụ xử lý mở rộng có thể được thực hiện bởi các ứng dụng khác nhau. Tại đây bạn có thể đặt ứng dụng nào sẽ được sử dụng cho tác vụ nào.",
    "Task:" : "Tác vụ:",
    "Here you can decide which group can access certain sections of the administration settings." : "Tại đây bạn có thể quyết định nhóm nào có thể truy cập các phần nhất định của cài đặt quản trị.",
    "Unable to modify setting" : "Không thể sửa đổi cài đặt",
    "None" : "Không gì cả",
    "Allow apps to use the Share API" : "Cho phép các ứng dụng sử dụng chia sẻ API",
    "Allow resharing" : "Cho phép chia sẻ lại",
    "Allow sharing with groups" : "Cho phép chia sẻ với các nhóm",
    "Restrict users to only share with users in their groups" : "Hạn chế người dùng chỉ chia sẻ với người dùng trong nhóm của họ",
    "Allow users to share via link and emails" : "Cho phép người dùng chia sẻ qua liên kết và email",
    "Allow public uploads" : "Cho phép upload công cộng",
    "Always ask for a password" : "Luôn yêu cầu mật khẩu",
    "Enforce password protection" : "Thực thi bảo vệ mật khẩu",
    "Enforce expiration date" : "Buộc có ngày hết hạn",
    "Set default expiration date for shares to other servers" : "Đặt ngày hết hạn mặc định cho việc chia sẻ sang các máy chủ khác",
    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Nếu tính năng tự động hoàn thành \"cùng nhóm\" và \"tích hợp số điện thoại\" được bật thì kết quả khớp trong cả hai đều đủ để hiển thị cho người dùng.",
    "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Cho phép tự động điền khi nhập họ tên hoặc địa chỉ email (bỏ qua trùng danh bạ bị thiếu và thuộc cùng một nhóm)",
    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Hiển thị văn bản từ chối trách nhiệm trên trang tải lên liên kết công khai (chỉ hiển thị khi danh sách tệp bị ẩn)",
    "This text will be shown on the public link upload page when the file list is hidden." : "Văn bản này sẽ được hiển thị trên trang tải lên liên kết công khai khi danh sách tệp bị ẩn.",
    "Default share permissions" : "Quyền chia sẻ mặc định",
    "Two-Factor Authentication" : "Xác thực hai yếu tố",
    "Enforce two-factor authentication" : "Thực thi xác thực hai yếu tố",
    "Limit to groups" : "Giới hạn nhóm",
    "Enforcement of two-factor authentication can be set for certain groups only." : "Việc thực thi xác thực hai yếu tố chỉ có thể được đặt cho một số nhóm nhất định.",
    "Two-factor authentication is enforced for all members of the following groups." : "Xác thực hai yếu tố được thực thi cho tất cả thành viên của các nhóm sau.",
    "Enforced groups" : "Các nhóm thực thi",
    "Two-factor authentication is not enforced for members of the following groups." : "Xác thực hai yếu tố không được thực thi đối với các thành viên của các nhóm sau.",
    "Excluded groups" : "Các nhóm bị loại trừ",
    "Save changes" : "Lưu thay đổi",
    "Update to {update}" : "Cập nhật tới {update}",
    "Remove" : "Xóa",
    "Featured" : "Tính năng được trang bị",
    "This app is supported via your current Nextcloud subscription." : "Ứng dụng này được hỗ trợ thông qua thuê bao Nextcloud hiện tại của bạn.",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Các ứng dụng nổi bật được phát triển bởi và trong cộng đồng. Chúng cung cấp chức năng trung tâm và sẵn sàng để sử dụng trong sản xuất.",
    "Disable all" : "Vô hiệu hóa tất cả",
    "Download and enable all" : "Tải xuống và kích hoạt tất cả",
    "All apps are up-to-date." : "Tất cả ứng dụng được cập nhật.",
    "Icon" : "Biểu tượng",
    "Name" : "Tên",
    "Version" : "Phiên bản",
    "Level" : "Cấp độ",
    "Actions" : "Hành động",
    "Results from other categories" : "Kết quả từ các danh mục khác",
    "No apps found for your version" : "Không tìm thấy ứng dụng nào cho phiên bản của bạn",
    "_%n app has an update available_::_%n apps have an update available_" : ["%n ứng dụng có sẵn bản cập nhật"],
    "_Update_::_Update all_" : ["Cập nhật tất cả"],
    "Failed to create group" : "Không tạo được nhóm",
    "Create group" : "Tạo nhóm",
    "Group name" : "Tên nhóm",
    "Please enter a valid group name" : "Vui lòng nhập tên nhóm hợp lệ",
    "Loading" : "Đang tải",
    "Type" : "Loại",
    "Learn more" : "Đọc nhiều hơn",
    "Confirm" : "Xác nhận",
    "Cancel" : "Hủy",
    "Description" : "Mô tả",
    "View in store" : "Xem tại cửa hàng",
    "Visit website" : "Truy cập trang web",
    "Admin documentation" : "Tài liệu quản trị",
    "Developer documentation" : "Tài liệu dành cho nhà phát triển",
    "Details" : "Chi tiết",
    "All" : "Tất cả",
    "Limit app usage to groups" : "Giới hạn sử dụng ứng dụng cho các nhóm",
    "No results" : "Không có kết quả",
    "Update to {version}" : "Cập nhật tới {version}",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Ứng dụng này không thể được cài đặt vì các điều kiện phụ thuộc sau không được đáp ứng:",
    "Categories" : "Các hạng mục",
    "Resources" : "Các nguồn lực",
    "Documentation" : "Tài liệu",
    "Report a bug" : "Báo cáo lỗi",
    "Request feature" : "Yêu cầu tính năng",
    "Ask questions or discuss" : "Hỏi các câu hỏi hoặc thảo luận",
    "Rate" : "Đánh giá",
    "Changelog" : "Sổ cập nhập thay đổi",
    "Google Chrome for Android" : "Google Chrome cho Android",
    "{productName} iOS app" : "Ứng dụng iOS {productName}",
    "{productName} Android app" : "Ứng dụng Android {productName}",
    "This session" : "Phiên này",
    "Device name" : "Tên thiết bị",
    "Marked for remote wipe" : "Đánh dấu để xóa từ xa",
    "Device settings" : "Cài đặt thiết bị",
    "Allow filesystem access" : "Cho phép truy cập file hệ thống",
    "Rename" : "Đổi tên",
    "Revoke" : "Thu hồi",
    "Wipe device" : "Xóa thiết bị",
    "Revoking this token might prevent the wiping of your device if it has not started the wipe yet." : "Việc thu hồi mã thông báo này có thể ngăn quá trình xóa thiết bị của bạn nếu thiết bị chưa bắt đầu quá trình xóa.",
    "Device" : "Thiết bị",
    "Last activity" : "Hoạt động cuối",
    "Devices & sessions" : "Thiết bị và phiên truy cập",
    "Web, desktop and mobile clients currently logged in to your account." : "Web, máy tính để bàn và máy khách di động hiện đang đăng nhập vào tài khoản của bạn.",
    "Error while creating device token" : "Lỗi trong khi tạo mã thông báo thiết bị",
    "App name" : "Tên ứng dụng",
    "Create new app password" : "Tạo ứng dụng mật khẩu mới",
    "Could not copy app password. Please copy it manually." : "Không thể sao chép ứng dụng mật khẩu. Vui lòng sao chép thủ công.",
    "Login" : "Đăng nhập",
    "Password" : "Mật khẩu",
    "Show QR code for mobile apps" : "Hiển thị mã QR cho ứng dụng di động",
    "Use system cron service to call the cron.php file every 5 minutes." : "Sử dụng dịch vụ cron hệ thống để gọi tệp cron.php cứ sau 5 phút.",
    "The PHP POSIX extension is required. See {linkstart}PHP documentation{linkend} for more details." : "Cần có phần mở rộng PHP POSIX. Xem {linkstart}tài liệu PHP{linkend} để biết thêm chi tiết.",
    "Unable to update background job mode" : "Không thể cập nhật chế độ công việc nền",
    "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information." : "Để máy chủ hoạt động bình thường, điều quan trọng là phải định cấu hình chính xác các công việc nền. Cron là cài đặt được đề xuất. Vui lòng xem tài liệu để biết thêm thông tin.",
    "Last job execution ran {time}. Something seems wrong." : "Lần thực hiện công việc cuối cùng đã diễn ra {time}. Có điều gì đó có vẻ không ổn.",
    "Last job ran {relativeTime}." : "Công việc cuối cùng đã chạy {relativeTime}.",
    "Background job did not run yet!" : "Công việc nền chưa chạy!",
    "Cron (Recommended)" : "Cron (Được khuyến nghị)",
    "Unable to update profile default setting" : "Không thể cập nhật cài đặt mặc định của hồ sơ",
    "Profile" : "Hồ sơ",
    "Unable to update server side encryption config" : "Không thể cập nhật cấu hình mã hóa phía máy chủ",
    "Server-side encryption" : "Mã hoá phía máy chủ",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Mã hóa phía máy chủ giúp mã hóa các tệp được tải lên máy chủ này. Điều này đi kèm với những hạn chế như hình phạt về hiệu suất, vì vậy chỉ kích hoạt tính năng này nếu cần.",
    "Enable server-side encryption" : "Kích hoạt mã hoá phía máy chủ",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Không có mô-đun mã hóa nào được tải, vui lòng bật mô-đun mã hóa trong menu ứng dụng.",
    "Select default encryption module:" : "Chọn mô-đun mã hóa mặc định:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}" : "Bạn cần di chuyển các khóa mã hóa của mình từ mã hóa cũ (ownCloud <= 8.0) sang mã hóa mới. Vui lòng bật \"Mô-đun mã hóa mặc định\" và chạy {command}",
    "Enable encryption" : "Bật mã hóa",
    "Please read carefully before activating server-side encryption:" : "Vui lòng đọc kỹ trước khi kích hoạt mã hóa phía máy chủ:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Sau khi bật mã hóa, tất cả các tệp được tải lên máy chủ từ thời điểm đó trở đi sẽ được mã hóa ở phần còn lại trên máy chủ. Sau này, bạn chỉ có thể tắt tính năng mã hóa nếu mô-đun mã hóa đang hoạt động hỗ trợ chức năng đó và đáp ứng tất cả các điều kiện trước (ví dụ: đặt khóa khôi phục).",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Mã hoá đơn phương không bảo đảm bảo mật hệ thống. Vui lòng xem tài liệu để biết thêm thông tin về cách hoạt động của mã hoá ứng dụng và những trường hợp hỗ trợ.",
    "Be aware that encryption always increases the file size." : "Xin lưu ý rằng mã hóa luôn làm tăng kích thước tệp.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Việc tạo bản sao lưu thường xuyên cho dữ liệu của bạn luôn là điều tốt, trong trường hợp mã hóa, hãy đảm bảo sao lưu các khóa mã hóa cùng với dữ liệu của bạn.",
    "This is the final warning: Do you really want to enable encryption?" : "Cảnh báo lần cuối: Bạn có thực sự muốn kích hoạt tính năng mã hoá?",
    "Please confirm the group removal" : "Vui lòng xác nhận việc xóa nhóm",
    "Submit" : "Gửi đi",
    "Rename group" : "Đổi tên nhóm",
    "Current password" : "Mật khẩu cũ",
    "New password" : "Mật khẩu mới",
    "Choose your profile picture" : "Chọn ảnh hồ sơ của bạn",
    "Please select a valid png or jpg file" : "Vui lòng chọn tệp png hoặc jpg hợp lệ",
    "Error setting profile picture" : "Lỗi cài đặt ảnh hồ sơ",
    "Error cropping profile picture" : "Lỗi cắt ảnh hồ sơ",
    "Error saving profile picture" : "Lỗi lưu ảnh hồ sơ",
    "Error removing profile picture" : "Lỗi xóa ảnh hồ sơ",
    "Your profile picture" : "Hình ảnh cá nhân của bạn",
    "Upload profile picture" : "Tải ảnh hồ sơ lên",
    "Choose profile picture from Files" : "Chọn ảnh hồ sơ từ Tệp",
    "Remove profile picture" : "Xóa ảnh hồ sơ",
    "The file must be a PNG or JPG" : "Tệp phải là PNG hoặc JPG",
    "Picture provided by original account" : "Hình ảnh do tài khoản gốc cung cấp",
    "Set as profile picture" : "Thiết lập như là hình ảnh hồ sơ cá nhân",
    "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "Xin lưu ý rằng có thể mất tới 24 giờ để ảnh hồ sơ của bạn được cập nhật ở mọi nơi.",
    "You are a member of the following groups:" : "Bạn là thành viên của các nhóm sau:",
    "Your full name" : "Tên đầy đủ của bạn",
    "Email options" : "Tùy chọn email",
    "Remove primary email" : "Xóa email chính",
    "Delete email" : "Xóa email",
    "This address is not confirmed" : "Địa chỉ này chưa được xác nhận",
    "Unset as primary email" : "Bỏ đặt làm email chính",
    "Set as primary email" : "Đặt làm email chính",
    "Additional email address {index}" : "Địa chỉ email bổ sung {index}",
    "Unable to delete primary email address" : "Không thể xóa địa chỉ email chính",
    "Unable to update primary email address" : "Không thể cập nhật địa chỉ email chính",
    "Unable to add additional email address" : "Không thể thêm địa chỉ email bổ sung",
    "Unable to update additional email address" : "Không thể cập nhật địa chỉ email bổ sung",
    "Unable to delete additional email address" : "Không thể xóa địa chỉ email bổ sung",
    "Primary email for password reset and notifications" : "Email chính để đặt lại mật khẩu và thông báo",
    "No email address set" : "Chưa thiết lập địa chỉ email",
    "Your headline" : "Tiêu đề của bạn",
    "Unable to update language" : "Không thể cập nhật ngôn ngữ",
    "Help translate" : "Hỗ trợ dịch thuật",
    "No language set" : "Không có ngôn ngữ",
    "Unable to update locale" : "Không thể cập nhật ngôn ngữ",
    "Week starts on {firstDayOfWeek}" : "Tuần bắt đầu vào {firstDayOfWeek}",
    "No locale set" : "Không có ngôn ngữ nào được đặt",
    "Your city" : "Thành phố",
    "Your organisation" : "Tổ chức",
    "Your phone number" : "Số điện thoại",
    "Edit your Profile visibility" : "Chỉnh sửa khả năng hiển thị Hồ sơ của bạn",
    "Unable to update profile enabled state" : "Không thể cập nhật trạng thái kích hoạt hồ sơ",
    "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "Cài đặt hạn chế hơn về khả năng hiển thị hoặc phạm vi được tôn trọng trên Hồ sơ của bạn. Ví dụ: nếu mức độ hiển thị được đặt thành \"Hiển thị cho mọi người\" và phạm vi được đặt thành \"Riêng tư\" thì \"Riêng tư\" sẽ được tôn trọng.",
    "Unable to update visibility of {displayId}" : "Không thể cập nhật mức độ hiển thị của {displayId}",
    "Your role" : "Vai trò của bạn",
    "Timezone" : "Múi giờ",
    "Your website" : "Trang web của bạn",
    "Unable to update {property}" : "Không thể cập nhật {property}",
    "No {property} set" : "Không có  {property} nào được đặt",
    "Change scope level of {property}, current scope is {scope}" : "Thay đổi cấp độ phạm vi của {property}, phạm vi hiện tại là {scope}",
    "Unable to update federation scope of the primary {property}" : "Không thể cập nhật phạm vi liên kết của {property} chính",
    "Unable to update federation scope of additional {property}" : "Không thể cập nhật phạm vi liên kết của {property} bổ sung",
    "Add additional email" : "Thêm email bổ sung",
    "Add" : "Thêm",
    "Create" : "Tạo",
    "Change" : "Thay đổi",
    "Delete" : "Xóa",
    "Reshare" : "Chia sẻ lại",
    "Default language" : "Ngôn ngữ mặc định",
    "Common languages" : "Ngôn ngữ thông dụng",
    "Other languages" : "Những ngôn ngữ khác",
    "Password change is disabled because the master key is disabled" : "Thay đổi mật khẩu bị vô hiệu hóa vì khóa chính bị vô hiệu hóa",
    "Manager" : "Giám đốc",
    "Either password or email is required" : "Cần có mật khẩu hoặc email",
    "Password (required)" : "Mật khẩu (được yêu câu)",
    "Email (required)" : "Email (bắt buộc)",
    "Email" : "Email",
    "Quota" : "Hạn ngạch",
    "Language" : "Ngôn ngữ",
    "Set default language" : "Đặt ngôn ngữ mặc định",
    "Total rows summary" : "Tổng số hàng",
    "Scroll to load more rows" : "Cuộn để tải thêm hàng",
    "Password or insufficient permissions message" : "Mật khẩu hoặc thông báo không đủ quyền",
    "Avatar" : "Hình đại diện",
    "Account name" : "Tên tài khoản",
    "Group admin for" : "Quản trị viên nhóm",
    "Storage location" : "Khu vực lưu trữ",
    "Last login" : "Lần đăng nhập cuối",
    "Account actions" : "Hành động với tài khoản",
    "{size} used" : "{size} đã sử dụng",
    "Delete account" : "Xóa tài khoản",
    "Resend welcome email" : "Gửi lại email chào mừng",
    "Remote wipe of devices" : "Xóa thiết bị từ xa",
    "Wipe {userid}'s devices" : "Xóa thiết bị của {userid}",
    "Wiped {userid}'s devices" : "Đã xóa thiết bị của {userid}",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "Xóa hoàn toàn tài khoản của {userid}, bao gồm tất cả các tệp cá nhân, dữ liệu ứng dụng của họ, v.v.",
    "Account deletion" : "Xóa tài khoản",
    "Delete {userid}'s account" : "Xóa tài khoản của {userid}",
    "Display name was successfully changed" : "Tên hiển thị đã được thay đổi thành công",
    "Password was successfully changed" : "Mật khẩu đã được thay đổi thành công",
    "Email was successfully changed" : "Email đã được thay đổi thành công",
    "Welcome mail sent!" : "Thư chào mừng đã được gửi!",
    "Change display name" : "Thay đổi tên hiển thị",
    "Set new password" : "Đặt mật khẩu mới",
    "Set new email address" : "Đặt địa chỉ email mới",
    "Set the language" : "Đặt ngôn ngữ",
    "Done" : "Hoàn tất",
    "Edit" : "Chỉnh sửa",
    "Visibility" : "Hiển thị",
    "Show language" : "Hiển thị ngôn ngữ",
    "Show storage path" : "Hiển thị đường dẫn lưu trữ",
    "Show last login" : "Hiển thị lần cuối đăng nhập",
    "Send email" : "Gửi email",
    "Defaults" : "Mặc định",
    "Default quota" : "Hạn ngạch mặc định",
    "Select default quota" : "Chọn hạn ngạch mặc định",
    "Server error while trying to complete WebAuthn device registration" : "Lỗi máy chủ khi cố gắng hoàn tất đăng ký thiết bị WebAuthn",
    "Passwordless authentication requires a secure connection." : "Xác thực không cần mật khẩu yêu cầu kết nối an toàn.",
    "Add WebAuthn device" : "Thêm thiết bị WebAuthn",
    "Please authorize your WebAuthn device." : "Vui lòng ủy quyền cho thiết bị WebAuthn của bạn.",
    "Adding your device …" : "Đang thêm thiết bị của bạn…",
    "Unnamed device" : "Thiết bị chưa được đặt tên",
    "Passwordless Authentication" : "Xác thực không cần mật khẩu",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "Thiết lập tài khoản của bạn để xác thực không cần mật khẩu theo tiêu chuẩn FIDO2.",
    "No devices configured." : "Không có thiết bị nào được định cấu hình.",
    "The following devices are configured for your account:" : "Các thiết bị sau được định cấu hình cho tài khoản của bạn:",
    "Your browser does not support WebAuthn." : "Trình duyệt của bạn không hỗ trợ WebAuthn.",
    "Security & setup warnings" : "Bảo mật và thiết lập cảnh báo",
    "Try again" : "Thử lại",
    "All checks passed." : "Tất cả các kiểm tra đã thoả điều kiện",
    "There are some errors regarding your setup." : "Có một số lỗi liên quan đến thiết lập của bạn.",
    "There are some warnings regarding your setup." : "Có một số cảnh báo liên quan đến thiết lập của bạn.",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Với tư cách là quản trị viên, bạn có thể tinh chỉnh hành vi chia sẻ. Vui lòng xem tài liệu để biết thêm thông tin.",
    "You need to enable the File sharing App." : "Bạn cần kích hoạt Ứng dụng chia sẻ tệp.",
    "Apply" : "Áp dụng",
    "Admins" : "Quản trị viên",
    "Sending…" : "Đang gửi...",
    "Email sent" : "Email đã được gửi",
    "Location" : "Vị trí",
    "Profile picture" : "Ảnh đại diện",
    "About" : "Giới thiệu",
    "Full name" : "Tên đầy đủ",
    "Additional email" : "Thư điện tử bổ sung",
    "Headline" : "Tiêu đề",
    "Organisation" : "Tổ chức",
    "Phone number" : "Số điện thoại",
    "Role" : "Vai trò",
    "Website" : "Website",
    "Profile visibility" : "Tấm nhìn hồ sơ",
    "Locale" : "Ngôn ngữ",
    "Not available as this property is required for core functionality including file sharing and calendar invitations" : "Không có sẵn vì thuộc tính này là bắt buộc đối với chức năng cốt lõi bao gồm chia sẻ tệp và lời mời lịch",
    "Your apps" : "Ứng dụng của bạn",
    "Active apps" : "Ứng dụng kích hoạt",
    "Disabled apps" : "Ứng dụng vô hiệu hóa",
    "Updates" : "Cập nhật",
    "App bundles" : "Gói ứng dụng",
    "Featured apps" : "Các ứng dụng đề xuất",
    "Supported apps" : "Ứng dụng được hỗ trợ",
    "Show to everyone" : "Hiển thị cho mọi người",
    "Hide" : "Ẩn",
    "Download and enable" : "Tải xuống và kích hoạt",
    "Disable" : "Tắt",
    "Allow untested app" : "Cho phép ứng dụng chưa được kiểm tra",
    "The app will be downloaded from the App Store" : "Ứng dụng sẽ được tải xuống từ App Store",
    "Unknown" : "Không xác định",
    "Never" : "Không bao giờ",
    "An error occurred during the request. Unable to proceed." : "Đã xảy ra lỗi trong quá trình yêu cầu. Không thể tiếp tục.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Lỗi: Không thể kích hoạt ứng dụng này vì nó khiến máy chủ không ổn định",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Ứng dụng đã được kích hoạt nhưng cần được cập nhật. Bạn sẽ được chuyển hướng đến trang cập nhật sau 5 giây.",
    "Do you really want to wipe your data from this device?" : "Bạn có thực sự muốn xóa dữ liệu của bạn khỏi thiết bị này?",
    "Confirm wipe" : "Xác nhận xóa",
    "Error while wiping the device with the token" : "Lỗi trong khi xóa thiết bị bằng mã thông báo",
    "Error while updating device token name" : "Lỗi trong khi cập nhật tên mã thông báo thiết bị",
    "Error while updating device token scope" : "Lỗi trong khi cập nhật phạm vi mã thông báo thiết bị",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Có quá nhiều yêu cầu từ mạng của bạn. Thử lại sau hoặc liên hệ với quản trị viên của bạn nếu đây là lỗi.",
    "Error" : "Lỗi",
    "Account documentation" : "Tài liệu tài khoản",
    "Administration documentation" : "Tài liệu hành chính",
    "Forum" : "Diễn đàn",
    "General documentation" : "Tài liệu chung",
    "Legal notice" : "Thông cáo pháp lý",
    "Privacy policy" : "Chính sách riêng tư",
    "Open documentation" : "Mở tài liệu",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Điều quan trọng là phải thiết lập máy chủ này để có thể gửi email, chẳng hạn như để đặt lại mật khẩu và thông báo.",
    "Send mode" : "Chế độ gửi",
    "Encryption" : "Mã hóa",
    "Sendmail mode" : "Chế độ gửi thư",
    "From address" : "Từ địa chỉ",
    "Server address" : "Địa chỉ máy chủ",
    "Port" : "Cổng",
    "Authentication" : "Xác thực",
    "Authentication required" : "Cần phải được xác thực",
    "Credentials" : "Giấy chứng nhận",
    "SMTP Password" : "Mật khẩu SMTP",
    "Save" : "Lưu",
    "Test and verify email settings" : "Kiểm tra và xác minh cài đặt email",
    "Use a second factor besides your password to increase security for your account." : "Sử dụng yếu tố thứ hai ngoài mật khẩu để tăng tính bảo mật cho tài khoản của bạn.",
    "Set default expiration date for shares" : "Đặt ngày hết hạn mặc định cho cổ phiếu",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Ứng dụng này không có phiên bản Nextcloud tối thiểu được chỉ định. Đây sẽ là một lỗi trong tương lai.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Ứng dụng này không có phiên bản Nextcloud tối đa được chỉ định. Đây sẽ là một lỗi trong tương lai.",
    "Your biography" : "Tiểu sử của bạn",
    "You are using <strong>{usage}</strong>" : "Bạn đang sử dụng {usage}",
    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Bạn đang sử dụng {usage} trên {totalSpace} ({usageRelative}%)",
    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Trong trường hợp thiết bị bị mất hoặc thoát khỏi tổ chức, thao tác này có thể xóa từ xa dữ liệu Nextcloud khỏi tất cả các thiết bị được liên kết với {userid}. Chỉ hoạt động nếu các thiết bị được kết nối với internet.",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Ứng dụng này không được đánh dấu là tương thích với phiên bản Nextcloud của bạn. Nếu bạn tiếp tục, bạn vẫn có thể cài đặt ứng dụng. Lưu ý rằng ứng dụng có thể không hoạt động như mong đợi.",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Điều quan trọng đối với tính bảo mật và hiệu suất của phiên bản của bạn là mọi thứ đều được đặt cấu hình chính xác. Để giúp bạn điều đó, chúng tôi đang thực hiện một số kiểm tra tự động. Vui lòng xem tài liệu được liên kết để biết thêm thông tin.",
    "Checking for system and security issues." : "Kiểm tra các vấn đề về hệ thống và bảo mật."
},
"nplurals=1; plural=0;");
